@@ -20,25 +20,37 @@ package org.apache.seatunnel.api.table.catalog;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 
-import lombok.AllArgsConstructor;
+import lombok.AccessLevel;
 import lombok.Data;
+import lombok.Getter;
 
 import java.io.Serializable;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import java.util.stream.Collectors;
 
 /** Represent a physical table schema. */
 @Data
-@AllArgsConstructor
 public final class TableSchema implements Serializable {
     private static final long serialVersionUID = 1L;
     private final List<Column> columns;
 
+    @Getter(AccessLevel.PRIVATE)
+    private final List<String> columnNames;
+
     private final PrimaryKey primaryKey;
 
     private final List<ConstraintKey> constraintKeys;
 
+    public TableSchema(
+            List<Column> columns, PrimaryKey primaryKey, List<ConstraintKey> constraintKeys) {
+        this.columns = columns;
+        this.columnNames = columns.stream().map(Column::getName).collect(Collectors.toList());
+        this.primaryKey = primaryKey;
+        this.constraintKeys = constraintKeys;
+    }
+
     public static Builder builder() {
         return new Builder();
     }
@@ -58,7 +70,23 @@ public final class TableSchema implements Serializable {
     }
 
     public String[] getFieldNames() {
-        return columns.stream().map(Column::getName).toArray(String[]::new);
+        return columnNames.toArray(new String[0]);
+    }
+
+    public int indexOf(String columnName) {
+        return columnNames.indexOf(columnName);
+    }
+
+    public Column getColumn(String columnName) {
+        return columns.get(indexOf(columnName));
+    }
+
+    public boolean contains(String columnName) {
+        return columnNames.contains(columnName);
+    }
+
+    public List<Column> getColumns() {
+        return Collections.unmodifiableList(columns);
     }
 
     public static final class Builder {
