@@ -74,6 +74,8 @@ public interface BasicDataConverter<T> extends DataConverter<T> {
                 return convertTime(value);
             case TIMESTAMP:
                 return convertLocalDateTime(value);
+            case TIMESTAMP_TZ:
+                return convertOffsetDateTime(value);
             case BYTES:
                 return convertBytes(value);
             case STRING:
@@ -123,6 +125,8 @@ public interface BasicDataConverter<T> extends DataConverter<T> {
                 return convertTime(typeDefine, value);
             case TIMESTAMP:
                 return convertLocalDateTime(typeDefine, value);
+            case TIMESTAMP_TZ:
+                return convertOffsetDateTime(typeDefine, value);
             case BYTES:
                 return convertBytes(typeDefine, value);
             case STRING:
@@ -434,6 +438,50 @@ public interface BasicDataConverter<T> extends DataConverter<T> {
                         + typeDefine);
     }
 
+    default OffsetDateTime convertOffsetDateTime(T typeDefine, Object value)
+            throws UnsupportedOperationException {
+        if (value instanceof OffsetDateTime) {
+            return (OffsetDateTime) value;
+        }
+        if (value instanceof LocalDateTime) {
+            return ((LocalDateTime) value).atZone(ZoneId.systemDefault()).toOffsetDateTime();
+        }
+        if (value instanceof Instant) {
+            return ((Instant) value).atZone(ZoneId.systemDefault()).toOffsetDateTime();
+        }
+        if (value instanceof java.sql.Date) {
+            return ((java.sql.Date) value)
+                    .toLocalDate()
+                    .atTime(LocalTime.MIDNIGHT)
+                    .atZone(ZoneId.systemDefault())
+                    .toOffsetDateTime();
+        }
+        if (value instanceof java.sql.Timestamp) {
+            return ((java.sql.Timestamp) value)
+                    .toInstant()
+                    .atZone(ZoneId.systemDefault())
+                    .toOffsetDateTime();
+        }
+        if (value instanceof Date) {
+            return ((Date) value).toInstant().atZone(ZoneId.systemDefault()).toOffsetDateTime();
+        }
+        if (value instanceof LocalDate) {
+            return ((LocalDate) value)
+                    .atTime(LocalTime.MIDNIGHT)
+                    .atZone(ZoneId.systemDefault())
+                    .toOffsetDateTime();
+        }
+        if (value instanceof String) {
+            return OffsetDateTime.parse((String) value);
+        }
+
+        throw new UnsupportedOperationException(
+                "Unsupported convert "
+                        + value.getClass()
+                        + " to OffsetDateTime, typeDefine: "
+                        + typeDefine);
+    }
+
     default LocalDateTime convertLocalDateTime(T typeDefine, Instant value) {
         return convertLocalDateTime(value);
     }
@@ -482,6 +530,47 @@ public interface BasicDataConverter<T> extends DataConverter<T> {
                 "Unsupported convert " + value.getClass() + " to LocalDateTime");
     }
 
+    default OffsetDateTime convertOffsetDateTime(Object value)
+            throws UnsupportedOperationException {
+        if (value instanceof OffsetDateTime) {
+            return (OffsetDateTime) value;
+        }
+        if (value instanceof LocalDateTime) {
+            return ((LocalDateTime) value).atZone(ZoneId.systemDefault()).toOffsetDateTime();
+        }
+        if (value instanceof Instant) {
+            return ((Instant) value).atZone(ZoneId.systemDefault()).toOffsetDateTime();
+        }
+        if (value instanceof java.sql.Date) {
+            return ((java.sql.Date) value)
+                    .toLocalDate()
+                    .atTime(LocalTime.MIDNIGHT)
+                    .atZone(ZoneId.systemDefault())
+                    .toOffsetDateTime();
+        }
+        if (value instanceof java.sql.Timestamp) {
+            return ((java.sql.Timestamp) value)
+                    .toInstant()
+                    .atZone(ZoneId.systemDefault())
+                    .toOffsetDateTime();
+        }
+        if (value instanceof Date) {
+            return ((Date) value).toInstant().atZone(ZoneId.systemDefault()).toOffsetDateTime();
+        }
+        if (value instanceof LocalDate) {
+            return ((LocalDate) value)
+                    .atTime(LocalTime.MIDNIGHT)
+                    .atZone(ZoneId.systemDefault())
+                    .toOffsetDateTime();
+        }
+        if (value instanceof String) {
+            return OffsetDateTime.parse((String) value);
+        }
+
+        throw new UnsupportedOperationException(
+                "Unsupported convert " + value.getClass() + " to LocalDateTime");
+    }
+
     default LocalDateTime convertLocalDateTime(Instant value) {
         return value.atZone(ZoneId.systemDefault()).toLocalDateTime();
     }
