@@ -65,11 +65,11 @@ public enum CommonErrorCode implements SeaTunnelErrorCode {
 
     WRITE_SEATUNNEL_ROW_ERROR_WITH_SCHEMA_INCOMPATIBLE_SCHEMA(
             "COMMON-30",
-            "<connector>: The source filed with schema '<sourceFieldSqlSchema>', except filed schema of sink is '<exceptFieldSqlSchema>'; but the filed in sink table which actual schema is '<sinkFieldSqlSchema>'. Please check schema of sink table."),
+            "'<connector>': The source field with schema '<sourceFieldSqlSchema>', expected field schema of sink is '<expectedFieldSqlSchema>'; whose actual schema in the sink table is '<sinkFieldSqlSchema>'. Please check schema of sink table."),
 
-    WRITE_SEATUNNEL_ROW_ERROR_WITH_FILEDS_NOT_MATCH(
+    WRITE_SEATUNNEL_ROW_ERROR_WITH_FIELDS_NOT_MATCH(
             "COMMON-31",
-            "<connector>: The source has '<sourceFieldsNum>' fields, but the table of sink has '<sinkFieldsNum>' fields. Please check schema of sink table."),
+            "'<connector>': The source has '<sourceFieldsNum>' fields, but the table of sink has '<sinkFieldsNum>' fields. Please check schema of sink table."),
     FORMAT_DATE_ERROR(
             "COMMON-32",
             "The date format '<date>' of field '<field>' is not supported. Please check the date format."),
