@@ -34,6 +34,8 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.isHeartbeatRecord;
+
 @Slf4j
 public class DebeziumJsonDeserializeSchema
         extends AbstractDebeziumDeserializationSchema<SeaTunnelRow> {
@@ -60,9 +62,13 @@ public class DebeziumJsonDeserializeSchema
     @Override
     public void deserialize(SourceRecord record, Collector<SeaTunnelRow> out) throws Exception {
         super.deserialize(record, out);
+        if (!isHeartbeatRecord(record)) {
+            SeaTunnelRow row = deserializationSchema.deserialize(record);
+            out.collect(row);
+            return;
+        }
 
-        SeaTunnelRow row = deserializationSchema.deserialize(record);
-        out.collect(row);
+        log.debug("Unsupported record {}, just skip.", record);
     }
 
     @Override
