@@ -19,6 +19,7 @@ package org.apache.seatunnel.connectors.seatunnel.cdc.mongodb;
 
 import org.apache.seatunnel.api.configuration.Option;
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
+import org.apache.seatunnel.api.source.SourceReader;
 import org.apache.seatunnel.api.source.SupportParallelism;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.connectors.cdc.base.config.SourceConfig;
@@ -28,6 +29,8 @@ import org.apache.seatunnel.connectors.cdc.base.option.StartupMode;
 import org.apache.seatunnel.connectors.cdc.base.option.StopMode;
 import org.apache.seatunnel.connectors.cdc.base.source.IncrementalSource;
 import org.apache.seatunnel.connectors.cdc.base.source.offset.OffsetFactory;
+import org.apache.seatunnel.connectors.cdc.base.source.split.SourceRecords;
+import org.apache.seatunnel.connectors.cdc.base.source.split.state.SourceSplitStateBase;
 import org.apache.seatunnel.connectors.cdc.debezium.DebeziumDeserializationSchema;
 import org.apache.seatunnel.connectors.cdc.debezium.DeserializeFormat;
 import org.apache.seatunnel.connectors.cdc.debezium.row.DebeziumJsonDeserializeSchema;
@@ -35,8 +38,10 @@ import org.apache.seatunnel.connectors.seatunnel.cdc.mongodb.config.MongodbSourc
 import org.apache.seatunnel.connectors.seatunnel.cdc.mongodb.config.MongodbSourceConfigProvider;
 import org.apache.seatunnel.connectors.seatunnel.cdc.mongodb.config.MongodbSourceOptions;
 import org.apache.seatunnel.connectors.seatunnel.cdc.mongodb.sender.MongoDBConnectorDeserializationSchema;
+import org.apache.seatunnel.connectors.seatunnel.cdc.mongodb.source.MongoDBRecordEmitter;
 import org.apache.seatunnel.connectors.seatunnel.cdc.mongodb.source.dialect.MongodbDialect;
 import org.apache.seatunnel.connectors.seatunnel.cdc.mongodb.source.offset.ChangeStreamOffsetFactory;
+import org.apache.seatunnel.connectors.seatunnel.common.source.reader.RecordEmitter;
 
 import javax.annotation.Nonnull;
 
@@ -123,4 +128,10 @@ public class MongodbIncrementalSource<T> extends IncrementalSource<T, MongodbSou
     public OffsetFactory createOffsetFactory(ReadonlyConfig config) {
         return new ChangeStreamOffsetFactory();
     }
+
+    @Override
+    protected RecordEmitter<SourceRecords, T, SourceSplitStateBase> createRecordEmitter(
+            SourceConfig sourceConfig, SourceReader.Context context) {
+        return new MongoDBRecordEmitter<>(deserializationSchema, offsetFactory, context);
+    }
 }
