@@ -25,12 +25,17 @@ import org.apache.seatunnel.connectors.seatunnel.clickhouse.exception.Clickhouse
 import org.apache.commons.lang3.StringUtils;
 import org.apache.sshd.client.SshClient;
 import org.apache.sshd.client.session.ClientSession;
+import org.apache.sshd.common.keyprovider.FileKeyPairProvider;
+import org.apache.sshd.common.keyprovider.KeyPairProvider;
 import org.apache.sshd.scp.client.ScpClient;
 import org.apache.sshd.scp.client.ScpClientCreator;
 
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
+import java.nio.file.Paths;
+import java.security.GeneralSecurityException;
+import java.security.KeyPair;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -42,15 +47,17 @@ public class ScpFileTransfer implements FileTransfer {
     private final String host;
     private final String user;
     private final String password;
+    private final String keyPath;
 
     private ScpClient scpClient;
     private ClientSession clientSession;
     private SshClient sshClient;
 
-    public ScpFileTransfer(String host, String user, String password) {
+    public ScpFileTransfer(String host, String user, String password, String keyPath) {
         this.host = host;
         this.user = user;
         this.password = password;
+        this.keyPath = keyPath;
     }
 
     @Override
@@ -62,14 +69,20 @@ public class ScpFileTransfer implements FileTransfer {
             if (password != null) {
                 clientSession.addPasswordIdentity(password);
             }
-            // TODO support add publicKey to identity
+            if (keyPath != null) {
+                FileKeyPairProvider fileKeyPairProvider =
+                        new FileKeyPairProvider(Paths.get(keyPath));
+                KeyPair fileKeyPair =
+                        fileKeyPairProvider.loadKey(clientSession, KeyPairProvider.SSH_RSA);
+                clientSession.addPublicKeyIdentity(fileKeyPair);
+            }
             if (!clientSession.auth().verify().isSuccess()) {
                 throw new ClickhouseConnectorException(
                         ClickhouseConnectorErrorCode.SSH_OPERATION_FAILED,
                         "ssh host " + host + "authentication failed");
             }
             scpClient = ScpClientCreator.instance().createScpClient(clientSession);
-        } catch (IOException e) {
+        } catch (IOException | GeneralSecurityException e) {
             throw new ClickhouseConnectorException(
                     ClickhouseConnectorErrorCode.SSH_OPERATION_FAILED,
                     "Failed to connect to host: " + host + " by user: " + user + " on port 22",
