@@ -19,4 +19,6 @@ package org.apache.seatunnel.connectors.seatunnel.clickhouse.state;
 
 import java.io.Serializable;
 
-public class CKAggCommitInfo implements Serializable {}
+public class CKAggCommitInfo implements Serializable {
+    private static final long serialVersionUID = 7725191558817348241L;
+}
