@@ -19,4 +19,6 @@ package org.apache.seatunnel.connectors.seatunnel.clickhouse.state;
 
 import java.io.Serializable;
 
-public class ClickhouseSinkState implements Serializable {}
+public class ClickhouseSinkState implements Serializable {
+    private static final long serialVersionUID = -2781233847929140233L;
+}
