@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.elasticsearch.dto.source;
 
+import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.JsonNode;
+
 import lombok.Data;
 
 import java.util.List;
@@ -27,4 +29,5 @@ public class ScrollResult {
 
     private String scrollId;
     private List<Map<String, Object>> docs;
+    private JsonNode columnNodes;
 }
