@@ -22,6 +22,7 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.JsonNode;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ArrayNode;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ObjectNode;
+import org.apache.seatunnel.shade.com.google.common.annotations.VisibleForTesting;
 
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
@@ -47,10 +48,13 @@ import java.math.BigDecimal;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
+import java.time.OffsetDateTime;
+import java.time.ZoneId;
 import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
+import java.util.function.Consumer;
 import java.util.function.Function;
 
 import static org.apache.seatunnel.api.table.type.SqlType.TIME;
@@ -105,26 +109,36 @@ public class FakeDataGenerator {
         return seaTunnelRow;
     }
 
+    @VisibleForTesting
+    public List<SeaTunnelRow> generateFakedRows(int rowNum) {
+        List<SeaTunnelRow> rows = new ArrayList<>();
+        generateFakedRows(rowNum, rows::add);
+        return rows;
+    }
+
     /**
      * @param rowNum The number of pieces of data to be generated by the current task
-     * @return The generated data
+     * @param consumer The generated data is sent to consumer
+     * @return The number of generated data row count
      */
-    public List<SeaTunnelRow> generateFakedRows(int rowNum) {
+    public long generateFakedRows(int rowNum, Consumer<SeaTunnelRow> consumer) {
         // Use manual configuration data preferentially
-        List<SeaTunnelRow> seaTunnelRows = new ArrayList<>();
+        long rowCount = 0;
         if (fakeConfig.getFakeRows() != null) {
             SeaTunnelDataType<?>[] fieldTypes = catalogTable.getSeaTunnelRowType().getFieldTypes();
             String[] fieldNames = catalogTable.getSeaTunnelRowType().getFieldNames();
             for (FakeConfig.RowData rowData : fakeConfig.getFakeRows()) {
                 customField(rowData, fieldTypes, fieldNames);
-                seaTunnelRows.add(convertRow(rowData));
+                consumer.accept(convertRow(rowData));
+                rowCount++;
             }
         } else {
             for (int i = 0; i < rowNum; i++) {
-                seaTunnelRows.add(randomRow());
+                consumer.accept(randomRow());
+                rowCount++;
             }
         }
-        return seaTunnelRows;
+        return rowCount;
     }
 
     private void customField(
@@ -172,6 +186,10 @@ public class FakeDataGenerator {
                 return fieldValue.equalsIgnoreCase(CURRENT_TIMESTAMP)
                         ? LocalDateTime.now().toString()
                         : null;
+            case TIMESTAMP_TZ:
+                return fieldValue.equalsIgnoreCase(CURRENT_TIMESTAMP)
+                        ? OffsetDateTime.now().toString()
+                        : null;
             default:
                 return null;
         }
@@ -280,6 +298,26 @@ public class FakeDataGenerator {
                                             : dateTimeFormatter);
                         },
                         fakeDataRandomUtils::randomLocalDateTime);
+            case TIMESTAMP_TZ:
+                return value(
+                        column,
+                        defaultValue -> {
+                            if (defaultValue.equalsIgnoreCase(CURRENT_TIMESTAMP)) {
+                                return OffsetDateTime.now();
+                            }
+                            DateTimeFormatter dateTimeFormatter =
+                                    DateTimeUtils.matchDateTimeFormatter(defaultValue);
+                            return OffsetDateTime.parse(
+                                    defaultValue,
+                                    dateTimeFormatter == null
+                                            ? DateTimeFormatter.ISO_OFFSET_DATE_TIME
+                                            : dateTimeFormatter);
+                        },
+                        c ->
+                                fakeDataRandomUtils
+                                        .randomLocalDateTime(c)
+                                        .atZone(ZoneId.systemDefault())
+                                        .toOffsetDateTime());
             case ROW:
                 SeaTunnelDataType<?>[] fieldTypes = ((SeaTunnelRowType) fieldType).getFieldTypes();
                 Object[] objects = new Object[fieldTypes.length];
