@@ -74,6 +74,17 @@ public class MultipleTableFileSourceSplitEnumerator
         this.assignedSplit.addAll(fileSourceState.getAssignedSplit());
     }
 
+    @Override
+    public void open() {
+        for (Map.Entry<String, List<String>> filePathEntry : filePathMap.entrySet()) {
+            String tableId = filePathEntry.getKey();
+            List<String> filePaths = filePathEntry.getValue();
+            for (String filePath : filePaths) {
+                allSplit.add(new FileSourceSplit(tableId, filePath));
+            }
+        }
+    }
+
     @Override
     public void addSplitsBack(List<FileSourceSplit> splits, int subtaskId) {
         if (CollectionUtils.isEmpty(splits)) {
@@ -92,16 +103,7 @@ public class MultipleTableFileSourceSplitEnumerator
     public void handleSplitRequest(int subtaskId) {}
 
     @Override
-    public void registerReader(int subtaskId) {
-        for (Map.Entry<String, List<String>> filePathEntry : filePathMap.entrySet()) {
-            String tableId = filePathEntry.getKey();
-            List<String> filePaths = filePathEntry.getValue();
-            for (String filePath : filePaths) {
-                allSplit.add(new FileSourceSplit(tableId, filePath));
-            }
-        }
-        assignSplit(subtaskId);
-    }
+    public void registerReader(int subtaskId) {}
 
     @Override
     public FileSourceState snapshotState(long checkpointId) {
@@ -149,14 +151,12 @@ public class MultipleTableFileSourceSplitEnumerator
         return assignCount % numReaders;
     }
 
-    @Override
-    public void open() {
-        // do nothing
-    }
-
     @Override
     public void run() throws Exception {
-        // do nothing
+        for (int i = 0; i < context.currentParallelism(); i++) {
+            log.info("Assigned splits to reader [{}]", i);
+            assignSplit(i);
+        }
     }
 
     @Override
