@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.file.ftp.system;
 
+import org.apache.seatunnel.connectors.seatunnel.file.ftp.config.FtpFileBaseOptions;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.commons.net.ftp.FTP;
@@ -66,6 +68,8 @@ public class SeaTunnelFTPFileSystem extends FileSystem {
     public static final String FS_FTP_HOST_PORT = "fs.ftp.host.port";
     public static final String FS_FTP_PASSWORD_PREFIX = "fs.ftp.password.";
     public static final String FS_FTP_CONNECTION_MODE = "fs.ftp.connection.mode";
+    public static final String FS_FTP_REMOTE_VERIFICATION_ENABLED =
+            "fs.ftp.remote.verification.enabled";
 
     public static final String E_SAME_DIRECTORY_ONLY = "only same directory renames are supported";
 
@@ -133,6 +137,13 @@ public class SeaTunnelFTPFileSystem extends FileSystem {
         String connectionMode =
                 conf.get(FS_FTP_CONNECTION_MODE, FtpConnectionMode.ACTIVE_LOCAL.getMode());
 
+        // Check if remote verification is enabled
+        boolean remoteVerificationEnabled =
+                conf.getBoolean(
+                        FS_FTP_REMOTE_VERIFICATION_ENABLED,
+                        FtpFileBaseOptions.FTP_REMOTE_VERIFICATION_ENABLED.defaultValue());
+        client.setRemoteVerificationEnabled(remoteVerificationEnabled);
+
         // Retrieve host, port, user, and password from configuration
         String host = conf.get(FS_FTP_HOST);
         int port = conf.getInt(FS_FTP_HOST_PORT, FTP.DEFAULT_PORT);
