@@ -29,12 +29,14 @@ import org.apache.seatunnel.common.config.CheckConfigUtil;
 import org.apache.seatunnel.common.config.CheckResult;
 import org.apache.seatunnel.common.constants.PluginType;
 import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
+import org.apache.seatunnel.connectors.seatunnel.file.config.FileBaseOptions;
+import org.apache.seatunnel.connectors.seatunnel.file.config.FileBaseSourceOptions;
 import org.apache.seatunnel.connectors.seatunnel.file.config.FileFormat;
 import org.apache.seatunnel.connectors.seatunnel.file.config.FileSystemType;
 import org.apache.seatunnel.connectors.seatunnel.file.exception.FileConnectorErrorCode;
 import org.apache.seatunnel.connectors.seatunnel.file.exception.FileConnectorException;
 import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.config.OssConf;
-import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.config.OssConfigOptions;
+import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.config.OssFileSourceOptions;
 import org.apache.seatunnel.connectors.seatunnel.file.oss.jindo.exception.OssJindoConnectorException;
 import org.apache.seatunnel.connectors.seatunnel.file.source.BaseFileSource;
 import org.apache.seatunnel.connectors.seatunnel.file.source.reader.ReadStrategyFactory;
@@ -55,12 +57,12 @@ public class OssFileSource extends BaseFileSource {
         CheckResult result =
                 CheckConfigUtil.checkAllExists(
                         pluginConfig,
-                        OssConfigOptions.FILE_PATH.key(),
-                        OssConfigOptions.FILE_FORMAT_TYPE.key(),
-                        OssConfigOptions.ENDPOINT.key(),
-                        OssConfigOptions.ACCESS_KEY.key(),
-                        OssConfigOptions.ACCESS_SECRET.key(),
-                        OssConfigOptions.BUCKET.key());
+                        FileBaseOptions.FILE_PATH.key(),
+                        FileBaseSourceOptions.FILE_FORMAT_TYPE.key(),
+                        OssFileSourceOptions.ENDPOINT.key(),
+                        OssFileSourceOptions.ACCESS_KEY.key(),
+                        OssFileSourceOptions.ACCESS_SECRET.key(),
+                        OssFileSourceOptions.BUCKET.key());
         if (!result.isSuccess()) {
             throw new OssJindoConnectorException(
                     SeaTunnelAPIErrorCode.CONFIG_VALIDATION_FAILED,
@@ -68,11 +70,11 @@ public class OssFileSource extends BaseFileSource {
                             "PluginName: %s, PluginType: %s, Message: %s",
                             getPluginName(), PluginType.SOURCE, result.getMsg()));
         }
-        String path = pluginConfig.getString(OssConfigOptions.FILE_PATH.key());
+        String path = pluginConfig.getString(FileBaseOptions.FILE_PATH.key());
         hadoopConf = OssConf.buildWithConfig(pluginConfig);
         readStrategy =
                 ReadStrategyFactory.of(
-                        pluginConfig.getString(OssConfigOptions.FILE_FORMAT_TYPE.key()));
+                        pluginConfig.getString(FileBaseSourceOptions.FILE_FORMAT_TYPE.key()));
         readStrategy.setPluginConfig(pluginConfig);
         readStrategy.init(hadoopConf);
         try {
@@ -86,7 +88,7 @@ public class OssFileSource extends BaseFileSource {
         FileFormat fileFormat =
                 FileFormat.valueOf(
                         pluginConfig
-                                .getString(OssConfigOptions.FILE_FORMAT_TYPE.key())
+                                .getString(FileBaseSourceOptions.FILE_FORMAT_TYPE.key())
                                 .toUpperCase());
         // only json text csv type support user-defined schema now
         if (pluginConfig.hasPath(ConnectorCommonOptions.SCHEMA.key())) {
