@@ -40,6 +40,7 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.net.URI;
 import java.net.URLDecoder;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Vector;
 
@@ -154,6 +155,29 @@ public class SFTPFileSystem extends FileSystem {
         }
     }
 
+    public String quote(String path) {
+        byte[] _path = path.getBytes(StandardCharsets.UTF_8);
+        int count = 0;
+        for (int i = 0; i < _path.length; i++) {
+            byte b = _path[i];
+            if (b == '\\' || b == '?' || b == '*') {
+                count++;
+            }
+        }
+        if (count == 0) {
+            return path;
+        }
+        byte[] _path2 = new byte[_path.length + count];
+        for (int i = 0, j = 0; i < _path.length; i++) {
+            byte b = _path[i];
+            if (b == '\\' || b == '?' || b == '*') {
+                _path2[j++] = '\\';
+            }
+            _path2[j++] = b;
+        }
+        return new String(_path2, 0, _path2.length, StandardCharsets.UTF_8);
+    }
+
     /**
      * Convenience method, so that we don't open a new connection when using this method from within
      * another method. Otherwise every API invocation incurs the overhead of opening/closing a TCP
@@ -466,7 +490,7 @@ public class SFTPFileSystem extends FileSystem {
             // the path could be a symbolic link, so get the real path
             absolute = new Path("/", channel.realpath(absolute.toUri().getPath()));
 
-            is = channel.get(absolute.toUri().getPath());
+            is = channel.get(quote(absolute.toUri().getPath()));
         } catch (SftpException e) {
             throw new IOException(e);
         }
