@@ -75,6 +75,17 @@ public class MultipleTableHiveSourceSplitEnumerator
         this.assignedSplit.addAll(localFileSourceState.getAssignedSplit());
     }
 
+    @Override
+    public void open() {
+        for (Map.Entry<String, List<String>> filePathEntry : filePathMap.entrySet()) {
+            String tableId = filePathEntry.getKey();
+            List<String> filePaths = filePathEntry.getValue();
+            for (String filePath : filePaths) {
+                allSplit.add(new FileSourceSplit(tableId, filePath));
+            }
+        }
+    }
+
     @Override
     public void addSplitsBack(List<FileSourceSplit> splits, int subtaskId) {
         if (CollectionUtils.isEmpty(splits)) {
@@ -93,16 +104,7 @@ public class MultipleTableHiveSourceSplitEnumerator
     public void handleSplitRequest(int subtaskId) {}
 
     @Override
-    public void registerReader(int subtaskId) {
-        for (Map.Entry<String, List<String>> filePathEntry : filePathMap.entrySet()) {
-            String tableId = filePathEntry.getKey();
-            List<String> filePaths = filePathEntry.getValue();
-            for (String filePath : filePaths) {
-                allSplit.add(new FileSourceSplit(tableId, filePath));
-            }
-        }
-        assignSplit(subtaskId);
-    }
+    public void registerReader(int subtaskId) {}
 
     @Override
     public FileSourceState snapshotState(long checkpointId) {
@@ -150,14 +152,12 @@ public class MultipleTableHiveSourceSplitEnumerator
         return assignCount % numReaders;
     }
 
-    @Override
-    public void open() {
-        // do nothing
-    }
-
     @Override
     public void run() throws Exception {
-        // do nothing
+        for (int i = 0; i < context.currentParallelism(); i++) {
+            log.info("Assigned splits to reader [{}]", i);
+            assignSplit(i);
+        }
     }
 
     @Override
