@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.http.source;
 
+import org.apache.seatunnel.shade.com.fasterxml.jackson.core.type.TypeReference;
+import org.apache.seatunnel.shade.com.google.common.annotations.VisibleForTesting;
 import org.apache.seatunnel.shade.com.google.common.base.Strings;
 
 import org.apache.seatunnel.api.serialization.DeserializationSchema;
@@ -28,6 +30,7 @@ import org.apache.seatunnel.connectors.seatunnel.common.source.AbstractSingleSpl
 import org.apache.seatunnel.connectors.seatunnel.common.source.SingleSplitReaderContext;
 import org.apache.seatunnel.connectors.seatunnel.http.client.HttpClientProvider;
 import org.apache.seatunnel.connectors.seatunnel.http.client.HttpResponse;
+import org.apache.seatunnel.connectors.seatunnel.http.config.HttpPaginationType;
 import org.apache.seatunnel.connectors.seatunnel.http.config.HttpParameter;
 import org.apache.seatunnel.connectors.seatunnel.http.config.JsonField;
 import org.apache.seatunnel.connectors.seatunnel.http.config.PageInfo;
@@ -148,27 +151,176 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
         }
     }
 
-    private void updateRequestParam(PageInfo pageInfo) {
-        // keep page param as http param
+    @VisibleForTesting
+    public void updateRequestParam(PageInfo pageInfo, boolean usePlaceholderReplacement) {
+        // 1. keep page param as http param
         if (this.httpParameter.isKeepPageParamAsHttpParam()) {
             if (this.httpParameter.getParams() == null) {
                 httpParameter.setParams(new HashMap<>());
             }
-            this.httpParameter
-                    .getParams()
-                    .put(pageInfo.getPageField(), pageInfo.getPageIndex().toString());
+            // keep page cursor as http param
+            if (pageInfo.getPageCursorFieldName() != null && pageInfo.getCursor() != null) {
+                this.httpParameter
+                        .getParams()
+                        .put(pageInfo.getPageCursorFieldName(), pageInfo.getCursor());
+            }
+
+            // keep page index as http param
+            if (pageInfo.getPageField() != null && pageInfo.getPageIndex() != null) {
+                this.httpParameter
+                        .getParams()
+                        .put(pageInfo.getPageField(), pageInfo.getPageIndex().toString());
+            }
             return;
         }
+        Long pageValue = pageInfo.getPageIndex();
+        String pageField = pageInfo.getPageField();
 
-        if (MapUtils.isNotEmpty(this.httpParameter.getParams())
-                && this.httpParameter.getParams().containsKey(pageInfo.getPageField())) {
-            this.httpParameter
-                    .getParams()
-                    .put(pageInfo.getPageField(), pageInfo.getPageIndex().toString());
+        // Process headers
+        if (MapUtils.isNotEmpty(this.httpParameter.getHeaders())) {
+            processPageMap(
+                    this.httpParameter.getHeaders(),
+                    pageField,
+                    pageValue.toString(),
+                    usePlaceholderReplacement);
+
+            processPageMap(
+                    this.httpParameter.getHeaders(),
+                    pageInfo.getPageCursorFieldName(),
+                    pageInfo.getCursor(),
+                    usePlaceholderReplacement);
         }
-        if (MapUtils.isNotEmpty(this.httpParameter.getBody())
-                && this.httpParameter.getBody().containsKey(pageInfo.getPageField())) {
-            this.httpParameter.getBody().put(pageInfo.getPageField(), pageInfo.getPageIndex());
+        // if not set keepPageParamAsHttpParam, but page field is in params, then set page index as
+        if (MapUtils.isNotEmpty(this.httpParameter.getParams())) {
+
+            processPageMap(
+                    this.httpParameter.getParams(),
+                    pageField,
+                    pageValue.toString(),
+                    usePlaceholderReplacement);
+            processPageMap(
+                    this.httpParameter.getParams(),
+                    pageInfo.getPageCursorFieldName(),
+                    pageInfo.getCursor(),
+                    usePlaceholderReplacement);
+        }
+
+        // 2. param in body
+        if (!Strings.isNullOrEmpty(this.httpParameter.getBody())) {
+            String processedBody =
+                    processBodyString(
+                            this.httpParameter.getBody(),
+                            pageField,
+                            pageValue,
+                            usePlaceholderReplacement);
+
+            // Process cursor if available
+            if (pageInfo.getPageCursorFieldName() != null && pageInfo.getCursor() != null) {
+                processedBody =
+                        processBodyString(
+                                processedBody,
+                                pageInfo.getPageCursorFieldName(),
+                                pageInfo.getCursor(),
+                                usePlaceholderReplacement);
+            }
+
+            // Update the body string
+            this.httpParameter.setBody(processedBody);
+        }
+    }
+
+    /**
+     * Replace placeholder in a string value
+     *
+     * @param value The string value that may contain a placeholder
+     * @param pageField The page field name
+     * @param pageValue The page value to replace the placeholder with
+     * @return The string with placeholder replaced, or null if no placeholder found
+     */
+    private String replacePlaceholder(String value, String pageField, Object pageValue) {
+        if (value == null || pageField == null || !value.contains("${" + pageField + "}")) {
+            return value;
+        }
+
+        String placeholder = "${" + pageField + "}";
+        int placeholderIndex = value.indexOf(placeholder);
+        if (placeholderIndex >= 0) {
+            String prefix = value.substring(0, placeholderIndex);
+            String suffix = value.substring(placeholderIndex + placeholder.length());
+            return prefix + pageValue + suffix;
+        }
+        return value;
+    }
+
+    private void processPageMap(
+            Map<String, String> map,
+            String pageField,
+            String pageValue,
+            boolean usePlaceholderReplacement) {
+        if (usePlaceholderReplacement) {
+            // Placeholder replacement
+            Map<String, String> updatedMap = new HashMap<>();
+            for (Map.Entry<String, String> entry : map.entrySet()) {
+                String key = entry.getKey();
+                String value = entry.getValue();
+                String replacedValue = replacePlaceholder(value, pageField, pageValue);
+                if (replacedValue != null) {
+                    updatedMap.put(key, replacedValue);
+                }
+            }
+            map.putAll(updatedMap);
+        } else if (map.containsKey(pageField)) {
+            // Key-based replacement
+            map.put(pageField, pageValue);
+        }
+    }
+
+    private String processBodyString(
+            String bodyString,
+            String pageField,
+            Object pageValue,
+            boolean usePlaceholderReplacement) {
+        if (pageField == null || pageValue == null || Strings.isNullOrEmpty(bodyString)) {
+            return bodyString;
+        }
+        if (usePlaceholderReplacement) {
+            String unquotedPlaceholder = "${" + pageField + "}";
+            if (bodyString.contains(unquotedPlaceholder)) {
+                bodyString = bodyString.replace(unquotedPlaceholder, pageValue.toString());
+            }
+
+            return bodyString;
+        } else {
+            // Key-based replacement
+            Map<String, Object> bodyMap =
+                    JsonUtils.parseObject(bodyString, new TypeReference<Map<String, Object>>() {});
+            if (bodyMap != null) {
+                processBodyMapRecursively(bodyMap, pageField, pageValue);
+                return JsonUtils.toJsonString(bodyMap);
+            }
+            return bodyString;
+        }
+    }
+
+    /**
+     * Process the body map recursively for key-based parameter replacement.
+     *
+     * @param bodyMap The body map to process
+     * @param pageField The page field name
+     * @param pageValue The page value
+     */
+    private void processBodyMapRecursively(
+            Map<String, Object> bodyMap, String pageField, Object pageValue) {
+        if (bodyMap.containsKey(pageField)) {
+            bodyMap.put(pageField, pageValue);
+        }
+        for (Map.Entry<String, Object> entry : bodyMap.entrySet()) {
+            Object value = entry.getValue();
+            if (value instanceof Map) {
+                @SuppressWarnings("unchecked")
+                Map<String, Object> nestedMap = (Map<String, Object>) value;
+                processBodyMapRecursively(nestedMap, pageField, pageValue);
+            }
         }
     }
 
@@ -185,15 +337,26 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
             if (pageInfoOptional.isPresent()) {
                 noMoreElementFlag = false;
                 PageInfo info = pageInfoOptional.get();
-                Long pageIndex = info.getPageIndex();
-                while (!noMoreElementFlag) {
-                    // increment page
-                    info.setPageIndex(pageIndex);
-                    // set request param
-                    updateRequestParam(info);
-                    pollAndCollectData(output);
-                    pageIndex += 1;
-                    Thread.sleep(10);
+                // cursor pagination
+                if (HttpPaginationType.CURSOR.getCode().equals(info.getPageType())) {
+                    while (!noMoreElementFlag) {
+                        updateRequestParam(info, info.isUsePlaceholderReplacement());
+                        pollAndCollectData(output);
+                        Thread.sleep(10);
+                    }
+
+                } else {
+                    // default page number pagination
+                    Long pageIndex = info.getPageIndex();
+                    while (!noMoreElementFlag) {
+                        // increment page
+                        info.setPageIndex(pageIndex);
+                        // set request param
+                        updateRequestParam(info, info.isUsePlaceholderReplacement());
+                        pollAndCollectData(output);
+                        pageIndex += 1;
+                        Thread.sleep(10);
+                    }
                 }
             } else {
                 pollAndCollectData(output);
@@ -212,29 +375,47 @@ public class HttpSourceReader extends AbstractSingleSplitReader<SeaTunnelRow> {
     }
 
     private void collect(Collector<SeaTunnelRow> output, String data) throws IOException {
+        String contentData = data;
         if (contentJson != null) {
-            data = JsonUtils.stringToJsonNode(getPartOfJson(data)).toString();
+            contentData = JsonUtils.stringToJsonNode(getPartOfJson(data)).toString();
         }
         if (jsonField != null && contentJson == null) {
             this.initJsonPath(jsonField);
-            data = JsonUtils.toJsonNode(parseToMap(decodeJSON(data), jsonField)).toString();
+            contentData = JsonUtils.toJsonNode(parseToMap(decodeJSON(data), jsonField)).toString();
         }
-        // page increase
+        // page
         if (pageInfoOptional.isPresent()) {
-            // Determine whether the task is completed by specifying the presence of the 'total
-            // page' field
             PageInfo pageInfo = pageInfoOptional.get();
-            if (pageInfo.getTotalPageSize() > 0) {
-                noMoreElementFlag = pageInfo.getPageIndex() >= pageInfo.getTotalPageSize();
+
+            // cursor pagination
+            if (HttpPaginationType.CURSOR.getCode().equals(pageInfo.getPageType())) {
+                // get cursor value from response JSON with fileName
+                String cursorResponseField = pageInfo.getPageCursorResponseField();
+                ReadContext context = JsonPath.using(jsonConfiguration).parse(data);
+                List<String> cursorList = context.read(cursorResponseField, List.class);
+                String newCursor = null;
+                if (cursorList != null && !cursorList.isEmpty()) {
+                    newCursor = cursorList.get(0);
+                }
+                pageInfo.setCursor(newCursor);
+                // if not present cursor, then no more data
+                noMoreElementFlag = Strings.isNullOrEmpty(newCursor);
             } else {
-                // no 'total page' configured
-                int readSize = JsonUtils.stringToJsonNode(data).size();
-                // if read size < BatchSize : read finish
-                // if read size = BatchSize : read next page.
-                noMoreElementFlag = readSize < pageInfo.getBatchSize();
+                // if not set page pagination is default
+                // Determine whether the task is completed by specifying the presence of the 'total
+                // page' field
+                if (pageInfo.getTotalPageSize() > 0) {
+                    noMoreElementFlag = pageInfo.getPageIndex() >= pageInfo.getTotalPageSize();
+                } else {
+                    // no 'total page' configured
+                    int readSize = JsonUtils.stringToJsonNode(contentData).size();
+                    // if read size < BatchSize : read finish
+                    // if read size = BatchSize : read next page.
+                    noMoreElementFlag = readSize < pageInfo.getBatchSize();
+                }
             }
         }
-        deserializationCollector.collect(data.getBytes(), output);
+        deserializationCollector.collect(contentData.getBytes(), output);
     }
 
     private List<Map<String, String>> parseToMap(List<List<String>> datas, JsonField jsonField) {
