@@ -17,15 +17,14 @@
 
 package org.apache.seatunnel.connectors.seatunnel.feishu.sink;
 
-import org.apache.seatunnel.shade.com.typesafe.config.Config;
-
+import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.connectors.seatunnel.http.sink.HttpSink;
 
 import java.util.Optional;
 
 public class FeishuSink extends HttpSink {
-    public FeishuSink(Config pluginConfig, CatalogTable catalogTable) {
+    public FeishuSink(ReadonlyConfig pluginConfig, CatalogTable catalogTable) {
         super(pluginConfig, catalogTable);
     }
 
