@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.influxdb.serialize;
 
+import org.apache.seatunnel.shade.com.google.common.base.Strings;
+
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
@@ -28,8 +30,6 @@ import org.apache.commons.lang3.StringUtils;
 
 import org.influxdb.dto.Point;
 
-import com.google.common.base.Strings;
-
 import java.time.LocalDateTime;
 import java.time.ZoneOffset;
 import java.util.List;
