@@ -19,46 +19,53 @@ package org.apache.seatunnel.connectors.seatunnel.jdbc.config;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 
+import lombok.Getter;
+
 import java.io.Serializable;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Optional;
 
+@Getter
 public class JdbcConnectionConfig implements Serializable {
     private static final long serialVersionUID = 2L;
 
-    public String url;
-    public String driverName;
-    public String compatibleMode;
-    public int connectionCheckTimeoutSeconds =
+    private String url;
+    private String driverName;
+    private String compatibleMode;
+    private int connectionCheckTimeoutSeconds =
             JdbcOptions.CONNECTION_CHECK_TIMEOUT_SEC.defaultValue();
-    public int maxRetries = JdbcOptions.MAX_RETRIES.defaultValue();
-    public String username;
-    public String password;
-    public String query;
+    private int maxRetries = JdbcOptions.MAX_RETRIES.defaultValue();
+    private String username;
+    private String password;
+    private String query;
 
-    public boolean autoCommit = JdbcOptions.AUTO_COMMIT.defaultValue();
+    private boolean autoCommit = JdbcOptions.AUTO_COMMIT.defaultValue();
 
-    public int batchSize = JdbcOptions.BATCH_SIZE.defaultValue();
+    private int batchSize = JdbcOptions.BATCH_SIZE.defaultValue();
 
-    public String xaDataSourceClassName;
+    private String xaDataSourceClassName;
 
-    public boolean decimalTypeNarrowing = JdbcOptions.DECIMAL_TYPE_NARROWING.defaultValue();
+    private boolean decimalTypeNarrowing = JdbcOptions.DECIMAL_TYPE_NARROWING.defaultValue();
 
-    public int maxCommitAttempts = JdbcOptions.MAX_COMMIT_ATTEMPTS.defaultValue();
+    private int maxCommitAttempts = JdbcOptions.MAX_COMMIT_ATTEMPTS.defaultValue();
 
-    public int transactionTimeoutSec = JdbcOptions.TRANSACTION_TIMEOUT_SEC.defaultValue();
+    private int transactionTimeoutSec = JdbcOptions.TRANSACTION_TIMEOUT_SEC.defaultValue();
 
-    public boolean useKerberos = JdbcOptions.USE_KERBEROS.defaultValue();
+    private boolean useKerberos = JdbcOptions.USE_KERBEROS.defaultValue();
 
-    public String kerberosPrincipal;
+    private String kerberosPrincipal;
 
-    public String kerberosKeytabPath;
+    private String kerberosKeytabPath;
 
-    public String krb5Path = JdbcOptions.KRB5_PATH.defaultValue();
+    private String krb5Path = JdbcOptions.KRB5_PATH.defaultValue();
+
+    private String dialect = JdbcOptions.DIALECT.defaultValue();
 
     private Map<String, String> properties;
 
+    private boolean handleBlobAsString = JdbcOptions.HANDLE_BLOB_AS_STRING.defaultValue();
+
     public static JdbcConnectionConfig of(ReadonlyConfig config) {
         JdbcConnectionConfig.Builder builder = JdbcConnectionConfig.builder();
         builder.url(config.get(JdbcOptions.URL));
@@ -68,6 +75,7 @@ public class JdbcConnectionConfig implements Serializable {
         builder.maxRetries(config.get(JdbcOptions.MAX_RETRIES));
         builder.connectionCheckTimeoutSeconds(config.get(JdbcOptions.CONNECTION_CHECK_TIMEOUT_SEC));
         builder.batchSize(config.get(JdbcOptions.BATCH_SIZE));
+        builder.handleBlobAsString(config.get(JdbcOptions.HANDLE_BLOB_AS_STRING));
         if (config.get(JdbcOptions.IS_EXACTLY_ONCE)) {
             builder.xaDataSourceClassName(config.get(JdbcOptions.XA_DATA_SOURCE_CLASS_NAME));
             builder.maxCommitAttempts(config.get(JdbcOptions.MAX_COMMIT_ATTEMPTS));
@@ -85,37 +93,10 @@ public class JdbcConnectionConfig implements Serializable {
         config.getOptional(JdbcOptions.PROPERTIES).ifPresent(builder::properties);
         config.getOptional(JdbcOptions.DECIMAL_TYPE_NARROWING)
                 .ifPresent(builder::decimalTypeNarrowing);
+        config.getOptional(JdbcOptions.DIALECT).ifPresent(builder::dialect);
         return builder.build();
     }
 
-    public String getUrl() {
-        return url;
-    }
-
-    public String getDriverName() {
-        return driverName;
-    }
-
-    public String getCompatibleMode() {
-        return compatibleMode;
-    }
-
-    public boolean isAutoCommit() {
-        return autoCommit;
-    }
-
-    public int getConnectionCheckTimeoutSeconds() {
-        return connectionCheckTimeoutSeconds;
-    }
-
-    public int getMaxRetries() {
-        return maxRetries;
-    }
-
-    public boolean isDecimalTypeNarrowing() {
-        return decimalTypeNarrowing;
-    }
-
     public Optional<String> getUsername() {
         return Optional.ofNullable(username);
     }
@@ -124,26 +105,10 @@ public class JdbcConnectionConfig implements Serializable {
         return Optional.ofNullable(password);
     }
 
-    public int getBatchSize() {
-        return batchSize;
-    }
-
-    public String getXaDataSourceClassName() {
-        return xaDataSourceClassName;
-    }
-
-    public int getMaxCommitAttempts() {
-        return maxCommitAttempts;
-    }
-
     public Optional<Integer> getTransactionTimeoutSec() {
         return transactionTimeoutSec < 0 ? Optional.empty() : Optional.of(transactionTimeoutSec);
     }
 
-    public Map<String, String> getProperties() {
-        return properties;
-    }
-
     public static JdbcConnectionConfig.Builder builder() {
         return new JdbcConnectionConfig.Builder();
     }
@@ -162,6 +127,7 @@ public class JdbcConnectionConfig implements Serializable {
         private int batchSize = JdbcOptions.BATCH_SIZE.defaultValue();
         private String xaDataSourceClassName;
         private boolean decimalTypeNarrowing = JdbcOptions.DECIMAL_TYPE_NARROWING.defaultValue();
+        private boolean handleBlobAsString = JdbcOptions.HANDLE_BLOB_AS_STRING.defaultValue();
         private int maxCommitAttempts = JdbcOptions.MAX_COMMIT_ATTEMPTS.defaultValue();
         private int transactionTimeoutSec = JdbcOptions.TRANSACTION_TIMEOUT_SEC.defaultValue();
         private Map<String, String> properties;
@@ -169,6 +135,7 @@ public class JdbcConnectionConfig implements Serializable {
         public String kerberosPrincipal;
         public String kerberosKeytabPath;
         public String krb5Path = JdbcOptions.KRB5_PATH.defaultValue();
+        public String dialect = JdbcOptions.DIALECT.defaultValue();
 
         private Builder() {}
 
@@ -262,11 +229,21 @@ public class JdbcConnectionConfig implements Serializable {
             return this;
         }
 
+        public Builder dialect(String dialect) {
+            this.dialect = dialect;
+            return this;
+        }
+
         public Builder properties(Map<String, String> properties) {
             this.properties = properties;
             return this;
         }
 
+        public Builder handleBlobAsString(boolean handleBlobAsString) {
+            this.handleBlobAsString = handleBlobAsString;
+            return this;
+        }
+
         public JdbcConnectionConfig build() {
             JdbcConnectionConfig jdbcConnectionConfig = new JdbcConnectionConfig();
             jdbcConnectionConfig.batchSize = this.batchSize;
@@ -282,13 +259,23 @@ public class JdbcConnectionConfig implements Serializable {
             jdbcConnectionConfig.maxCommitAttempts = this.maxCommitAttempts;
             jdbcConnectionConfig.xaDataSourceClassName = this.xaDataSourceClassName;
             jdbcConnectionConfig.decimalTypeNarrowing = this.decimalTypeNarrowing;
+            jdbcConnectionConfig.handleBlobAsString = this.handleBlobAsString;
             jdbcConnectionConfig.useKerberos = this.useKerberos;
             jdbcConnectionConfig.kerberosPrincipal = this.kerberosPrincipal;
             jdbcConnectionConfig.kerberosKeytabPath = this.kerberosKeytabPath;
             jdbcConnectionConfig.krb5Path = this.krb5Path;
+            jdbcConnectionConfig.dialect = this.dialect;
             jdbcConnectionConfig.properties =
                     this.properties == null ? new HashMap<>() : this.properties;
             return jdbcConnectionConfig;
         }
     }
+
+    public boolean isHandleBlobAsString() {
+        return handleBlobAsString;
+    }
+
+    public void setHandleBlobAsString(boolean handleBlobAsString) {
+        this.handleBlobAsString = handleBlobAsString;
+    }
 }
