@@ -29,6 +29,11 @@ import javax.annotation.Nonnull;
 /** Factory for {@link MysqlDialect}. */
 @AutoService(JdbcDialectFactory.class)
 public class MySqlDialectFactory implements JdbcDialectFactory {
+    @Override
+    public String dialectFactoryName() {
+        return DatabaseIdentifier.MYSQL;
+    }
+
     @Override
     public boolean acceptsURL(String url) {
         return url.startsWith("jdbc:mysql:");
