@@ -25,6 +25,7 @@ import org.apache.seatunnel.api.table.schema.event.AlterTableAddColumnEvent;
 import org.apache.seatunnel.api.table.schema.event.AlterTableChangeColumnEvent;
 import org.apache.seatunnel.api.table.schema.event.AlterTableColumnEvent;
 import org.apache.seatunnel.api.table.schema.event.AlterTableModifyColumnEvent;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcOptions;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.converter.JdbcRowConverter;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialect;
@@ -53,12 +54,20 @@ public class OracleDialect implements JdbcDialect {
 
     private static final int DEFAULT_ORACLE_FETCH_SIZE = 128;
     public String fieldIde = FieldIdeEnum.ORIGINAL.getValue();
+    private final boolean handleBlobAsString;
 
     public OracleDialect(String fieldIde) {
-        this.fieldIde = fieldIde;
+        this(fieldIde, JdbcOptions.HANDLE_BLOB_AS_STRING.defaultValue());
     }
 
-    public OracleDialect() {}
+    public OracleDialect() {
+        this(FieldIdeEnum.ORIGINAL.getValue(), JdbcOptions.HANDLE_BLOB_AS_STRING.defaultValue());
+    }
+
+    public OracleDialect(String fieldIde, boolean handleBlobAsString) {
+        this.fieldIde = fieldIde;
+        this.handleBlobAsString = handleBlobAsString;
+    }
 
     @Override
     public String dialectName() {
@@ -72,7 +81,7 @@ public class OracleDialect implements JdbcDialect {
 
     @Override
     public TypeConverter<BasicTypeDefine> getTypeConverter() {
-        return OracleTypeConverter.INSTANCE;
+        return new OracleTypeConverter(true, handleBlobAsString);
     }
 
     @Override
@@ -82,7 +91,7 @@ public class OracleDialect implements JdbcDialect {
 
     @Override
     public JdbcDialectTypeMapper getJdbcDialectTypeMapper() {
-        return new OracleTypeMapper();
+        return new OracleTypeMapper(true, handleBlobAsString);
     }
 
     @Override
@@ -482,4 +491,24 @@ public class OracleDialect implements JdbcDialect {
             return rs.getString("NULLABLE").equals("Y");
         }
     }
+
+    @Override
+    public String dualTable() {
+        return " FROM dual ";
+    }
+
+    @Override
+    public String getCollateSql(String collate) {
+        if (StringUtils.isNotBlank(collate)) {
+            StringBuilder sql = new StringBuilder();
+            sql.append("NLSSORT(")
+                    .append("char_val")
+                    .append(", 'NLS_SORT=")
+                    .append(collate)
+                    .append("')");
+            return sql.toString();
+        } else {
+            return "char_val";
+        }
+    }
 }
