@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.phoenix;
 
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialect;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.JdbcDialectFactory;
 
@@ -26,6 +27,11 @@ import lombok.NonNull;
 @AutoService(JdbcDialectFactory.class)
 public class PhoenixDialectFactory implements JdbcDialectFactory {
 
+    @Override
+    public String dialectFactoryName() {
+        return DatabaseIdentifier.PHOENIX;
+    }
+
     @Override
     public boolean acceptsURL(@NonNull String url) {
         return url.startsWith("jdbc:phoenix:");
