@@ -159,10 +159,16 @@ public class MaxComputeCatalogUtil {
     public static String columnToMaxComputeType(
             Column column, TypeConverter<BasicTypeDefine<TypeInfo>> typeConverter) {
         checkNotNull(column, "The column is required.");
+        String columnType;
+        if (column.getSinkType() != null) {
+            columnType = column.getSinkType();
+        } else {
+            columnType = typeConverter.reconvert(column).getColumnType();
+        }
         return String.format(
                 "`%s` %s %s %s",
                 column.getName(),
-                typeConverter.reconvert(column).getColumnType(),
+                columnType,
                 column.isNullable() ? "NULL" : "NOT NULL",
                 StringUtils.isEmpty(column.getComment())
                         ? ""
