@@ -25,40 +25,33 @@ import org.apache.seatunnel.api.table.connector.TableSink;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactoryContext;
+import org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeSinkOptions;
 
 import com.google.auto.service.AutoService;
 
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.ACCESS_ID;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.ACCESS_KEY;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.CUSTOM_SQL;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.DATA_SAVE_MODE;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.ENDPOINT;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.OVERWRITE;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.PARTITION_SPEC;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.PLUGIN_NAME;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.PROJECT;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.SAVE_MODE_CREATE_TEMPLATE;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.SCHEMA_SAVE_MODE;
-import static org.apache.seatunnel.connectors.seatunnel.maxcompute.config.MaxcomputeConfig.TABLE_NAME;
-
 @AutoService(Factory.class)
 public class MaxcomputeSinkFactory implements TableSinkFactory {
     @Override
     public String factoryIdentifier() {
-        return PLUGIN_NAME;
+        return MaxcomputeSinkOptions.PLUGIN_NAME;
     }
 
     @Override
     public OptionRule optionRule() {
         return OptionRule.builder()
-                .required(ACCESS_ID, ACCESS_KEY, ENDPOINT, PROJECT, TABLE_NAME)
+                .required(
+                        MaxcomputeSinkOptions.ACCESS_ID,
+                        MaxcomputeSinkOptions.ACCESS_KEY,
+                        MaxcomputeSinkOptions.ENDPOINT,
+                        MaxcomputeSinkOptions.PROJECT,
+                        MaxcomputeSinkOptions.TABLE_NAME)
                 .optional(
-                        PARTITION_SPEC,
-                        OVERWRITE,
-                        SCHEMA_SAVE_MODE,
-                        DATA_SAVE_MODE,
-                        SAVE_MODE_CREATE_TEMPLATE,
-                        CUSTOM_SQL,
+                        MaxcomputeSinkOptions.PARTITION_SPEC,
+                        MaxcomputeSinkOptions.OVERWRITE,
+                        MaxcomputeSinkOptions.SCHEMA_SAVE_MODE,
+                        MaxcomputeSinkOptions.DATA_SAVE_MODE,
+                        MaxcomputeSinkOptions.SAVE_MODE_CREATE_TEMPLATE,
+                        MaxcomputeSinkOptions.CUSTOM_SQL,
                         SinkConnectorCommonOptions.MULTI_TABLE_SINK_REPLICA)
                 .build();
     }
@@ -71,8 +64,8 @@ public class MaxcomputeSinkFactory implements TableSinkFactory {
                         CatalogTable.of(
                                 TableIdentifier.of(
                                         context.getCatalogTable().getCatalogName(),
-                                        context.getOptions().get(PROJECT),
-                                        context.getOptions().get(TABLE_NAME)),
+                                        context.getOptions().get(MaxcomputeSinkOptions.PROJECT),
+                                        context.getOptions().get(MaxcomputeSinkOptions.TABLE_NAME)),
                                 context.getCatalogTable()));
     }
 }
