@@ -18,6 +18,7 @@
 package org.apache.seatunnel.connectors.seatunnel.maxcompute;
 
 import org.apache.seatunnel.api.table.type.BasicType;
+import org.apache.seatunnel.api.table.type.LocalTimeType;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
@@ -33,6 +34,8 @@ import com.aliyun.odps.data.ArrayRecord;
 import com.aliyun.odps.data.Record;
 import lombok.SneakyThrows;
 
+import java.time.LocalDate;
+
 public class BasicTypeToOdpsTypeTest {
 
     private static void testType(
@@ -102,4 +105,10 @@ public class BasicTypeToOdpsTypeTest {
     void testVOID_TYPE_2_VOID() {
         testType("VOID_TYPE_2_VOID", BasicType.VOID_TYPE, OdpsType.VOID, null);
     }
+
+    @SneakyThrows
+    @Test
+    void testDATE_TYPE_2_DATE() {
+        testType("DATE_TYPE_2_DATE", LocalTimeType.LOCAL_DATE_TYPE, OdpsType.DATE, LocalDate.now());
+    }
 }
