@@ -19,10 +19,10 @@ package org.apache.seatunnel.connectors.seatunnel.mongodb.source;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.configuration.util.OptionRule;
+import org.apache.seatunnel.api.options.ConnectorCommonOptions;
 import org.apache.seatunnel.api.source.SeaTunnelSource;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.CatalogTableUtil;
-import org.apache.seatunnel.api.table.catalog.schema.TableSchemaOptions;
 import org.apache.seatunnel.api.table.connector.TableSource;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableSourceFactory;
@@ -51,7 +51,7 @@ public class MongodbSourceFactory implements TableSourceFactory {
                         MongodbConfig.URI,
                         MongodbConfig.DATABASE,
                         MongodbConfig.COLLECTION,
-                        TableSchemaOptions.SCHEMA)
+                        ConnectorCommonOptions.SCHEMA)
                 .optional(
                         MongodbConfig.PROJECTION,
                         MongodbConfig.MATCH_QUERY,
@@ -75,7 +75,7 @@ public class MongodbSourceFactory implements TableSourceFactory {
         return () -> {
             ReadonlyConfig options = context.getOptions();
             CatalogTable table;
-            if (options.getOptional(TableSchemaOptions.SCHEMA).isPresent()) {
+            if (options.getOptional(ConnectorCommonOptions.SCHEMA).isPresent()) {
                 table = CatalogTableUtil.buildWithConfig(options);
             } else {
                 table = CatalogTableUtil.buildSimpleTextTable();
