@@ -27,8 +27,6 @@ import org.apache.seatunnel.e2e.sink.inmemory.InMemorySinkWriter;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Order;
 import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.condition.DisabledOnJre;
-import org.junit.jupiter.api.condition.JRE;
 
 import lombok.extern.slf4j.Slf4j;
 
@@ -45,11 +43,6 @@ import java.util.List;
 public class MultiTableSinkTest {
 
     @Test
-    @DisabledOnJre(
-            value = JRE.JAVA_11,
-            disabledReason =
-                    "We should update apache common lang3 version to 3.8 to avoid NPE, "
-                            + "see https://github.com/apache/commons-lang/commit/50ce8c44e1601acffa39f5568f0fc140aade0564")
     public void testMultiTableSink()
             throws FileNotFoundException, URISyntaxException, CommandException {
         String configurePath = "/config/fake_to_inmemory_multi_table.conf";
