@@ -23,6 +23,11 @@ import org.apache.seatunnel.core.starter.exception.CommandException;
 import org.apache.seatunnel.core.starter.seatunnel.args.ClientCommandArgs;
 import org.apache.seatunnel.core.starter.utils.CommandLineUtils;
 
+import org.apache.commons.lang3.exception.ExceptionUtils;
+
+import lombok.extern.slf4j.Slf4j;
+
+@Slf4j
 public class SeaTunnelClient {
     public static void main(String[] args) throws CommandException {
         ClientCommandArgs clientCommandArgs =
@@ -31,6 +36,11 @@ public class SeaTunnelClient {
                         new ClientCommandArgs(),
                         EngineType.SEATUNNEL.getStarterShellName(),
                         true);
-        SeaTunnel.run(clientCommandArgs.buildCommand());
+        try {
+            SeaTunnel.run(clientCommandArgs.buildCommand());
+        } catch (Error e) {
+            log.error("Exception StackTrace: {}", ExceptionUtils.getStackTrace(e));
+            System.exit(1);
+        }
     }
 }
