@@ -48,6 +48,7 @@ import org.apache.iceberg.io.FileAppenderFactory;
 import org.apache.iceberg.types.Types;
 
 import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.TestTemplate;
@@ -59,6 +60,11 @@ import lombok.extern.slf4j.Slf4j;
 import java.io.IOException;
 import java.math.BigDecimal;
 import java.nio.ByteBuffer;
+import java.nio.file.FileVisitResult;
+import java.nio.file.Path;
+import java.nio.file.Paths;
+import java.nio.file.SimpleFileVisitor;
+import java.nio.file.attribute.BasicFileAttributes;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
@@ -130,6 +136,35 @@ public class IcebergSourceIT extends TestSuiteBase implements TestResource {
     @Override
     public void tearDown() throws Exception {}
 
+    @AfterEach
+    public void clean() {
+        // clean the catalog dir
+        Path catalogPath = Paths.get(CATALOG_DIR);
+        if (java.nio.file.Files.exists(catalogPath)) {
+            try {
+                java.nio.file.Files.walkFileTree(
+                        catalogPath,
+                        new SimpleFileVisitor<Path>() {
+                            @Override
+                            public FileVisitResult visitFile(Path file, BasicFileAttributes attrs)
+                                    throws IOException {
+                                java.nio.file.Files.delete(file);
+                                return FileVisitResult.CONTINUE;
+                            }
+
+                            @Override
+                            public FileVisitResult postVisitDirectory(Path dir, IOException exc)
+                                    throws IOException {
+                                java.nio.file.Files.delete(dir);
+                                return FileVisitResult.CONTINUE;
+                            }
+                        });
+            } catch (IOException e) {
+                throw new RuntimeException(e);
+            }
+        }
+    }
+
     @TestTemplate
     public void testIcebergSource(TestContainer container)
             throws IOException, InterruptedException {
@@ -137,6 +172,22 @@ public class IcebergSourceIT extends TestSuiteBase implements TestResource {
         Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
     }
 
+    @TestTemplate
+    public void testFilterIcebergSourceSingleTable(TestContainer container)
+            throws IOException, InterruptedException {
+        Container.ExecResult execResult =
+                container.executeJob("/iceberg/filter_iceberg_source.conf");
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+    }
+
+    @TestTemplate
+    public void testFilterIcebergSourceTables(TestContainer container)
+            throws IOException, InterruptedException {
+        Container.ExecResult execResult =
+                container.executeJob("/iceberg/filter_iceberg_source_tables.conf");
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+    }
+
     private void initializeIcebergTable() {
 
         Map<String, Object> configs = new HashMap<>();
