@@ -481,7 +481,8 @@ public class PaimonSinkDynamicBucketIT extends TestSuiteBase implements TestReso
                                         row.getDecimal(10, 30, 8),
                                         row.getString(11),
                                         row.getInt(12),
-                                        row.getTimestamp(13, 6));
+                                        row.getTimestamp(13, 6),
+                                        row.getInt(14));
                         result.add(paimonRecordWithFullType);
                     });
         } catch (IOException e) {
