@@ -134,6 +134,8 @@ public class PaimonSinkWithSchemaEvolutionIT extends AbstractPaimonIT implements
     @BeforeAll
     @Override
     public void startUp() throws Exception {
+        this.isWindows =
+                System.getProperties().getProperty("os.name").toUpperCase().contains("WINDOWS");
         log.info("The second stage: Starting Mysql containers...");
         Startables.deepStart(Stream.of(MYSQL_CONTAINER)).join();
         log.info("Mysql Containers are started");
@@ -368,7 +370,8 @@ public class PaimonSinkWithSchemaEvolutionIT extends AbstractPaimonIT implements
                         "mysql",
                         MYSQL_USER_NAME,
                         MYSQL_USER_PASSWORD,
-                        JdbcUrlUtil.getUrlInfo(MYSQL_CONTAINER.getJdbcUrl()))) {
+                        JdbcUrlUtil.getUrlInfo(MYSQL_CONTAINER.getJdbcUrl()),
+                        null)) {
             mySqlCatalog.open();
             CatalogTable mySqlCatalogTable =
                     mySqlCatalog.getTable(TablePath.of(MYSQL_DATABASE, SOURCE_TABLE));
