@@ -23,6 +23,7 @@ import org.apache.seatunnel.e2e.common.junit.ContainerTestingExtension;
 import org.apache.seatunnel.e2e.common.junit.TestCaseInvocationContextProvider;
 import org.apache.seatunnel.e2e.common.junit.TestContainers;
 import org.apache.seatunnel.e2e.common.junit.TestLoggerExtension;
+import org.apache.seatunnel.e2e.common.junit.TimingExtension;
 import org.apache.seatunnel.e2e.common.util.ContainerUtil;
 
 import org.junit.jupiter.api.TestInstance;
@@ -35,7 +36,8 @@ import com.github.dockerjava.api.DockerClient;
 @ExtendWith({
     ContainerTestingExtension.class,
     TestLoggerExtension.class,
-    TestCaseInvocationContextProvider.class
+    TestCaseInvocationContextProvider.class,
+    TimingExtension.class
 })
 @TestInstance(TestInstance.Lifecycle.PER_CLASS)
 public abstract class TestSuiteBase {
