@@ -31,8 +31,10 @@ import org.testcontainers.utility.DockerLoggerFactory;
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
+import java.nio.file.Paths;
 import java.time.Duration;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.stream.Stream;
 
@@ -87,6 +89,11 @@ public abstract class AbstractTestSparkContainer extends AbstractTestContainer {
         throw new UnsupportedOperationException("Not implemented");
     }
 
+    @Override
+    protected String getCancelJobCommand() {
+        throw new UnsupportedOperationException("Not implemented");
+    }
+
     @Override
     protected String getRestoreCommand() {
         throw new UnsupportedOperationException("Not implemented");
@@ -105,14 +112,14 @@ public abstract class AbstractTestSparkContainer extends AbstractTestContainer {
     @Override
     public Container.ExecResult executeJob(String confFile)
             throws IOException, InterruptedException {
-        return executeJob(confFile, null);
+        return executeJob(confFile, Collections.emptyList());
     }
 
     @Override
     public Container.ExecResult executeJob(String confFile, List<String> variables)
             throws IOException, InterruptedException {
         log.info("test in container: {}", identifier());
-        return executeJob(master, confFile, variables);
+        return executeJob(master, confFile, null, variables);
     }
 
     @Override
@@ -125,4 +132,9 @@ public abstract class AbstractTestSparkContainer extends AbstractTestContainer {
         ContainerUtil.copyFileIntoContainers(
                 ContainerUtil.getResourcesFile(path).toPath(), targetPath, master);
     }
+
+    @Override
+    public void copyAbsolutePathToContainer(String path, String targetPath) {
+        ContainerUtil.copyFileIntoContainers(Paths.get(path), targetPath, master);
+    }
 }
