@@ -25,6 +25,7 @@ import com.hazelcast.internal.config.YamlConfigLocator;
 import lombok.NonNull;
 
 import java.io.ByteArrayInputStream;
+import java.util.Arrays;
 import java.util.Properties;
 
 import static com.hazelcast.internal.config.DeclarativeConfigUtil.SYSPROP_CLIENT_CONFIG;
@@ -112,6 +113,10 @@ public final class ConfigProvider {
             yamlConfigLocator.locateDefault();
             config = new YamlClientConfigBuilder(yamlConfigLocator.getIn()).build();
         }
+        String stDockerMemberList = System.getenv("ST_DOCKER_MEMBER_LIST");
+        if (stDockerMemberList != null) {
+            config.getNetworkConfig().setAddresses(Arrays.asList(stDockerMemberList.split(",")));
+        }
         return config;
     }
 
@@ -141,6 +146,15 @@ public final class ConfigProvider {
                             .setProperties(properties)
                             .build();
         }
+        String stDockerMemberList = System.getenv("ST_DOCKER_MEMBER_LIST");
+        if (stDockerMemberList != null) {
+            if (config.getNetworkConfig().getJoin().getTcpIpConfig().isEnabled()) {
+                config.getNetworkConfig()
+                        .getJoin()
+                        .getTcpIpConfig()
+                        .setMembers(Arrays.asList(stDockerMemberList.split(",")));
+            }
+        }
         return config;
     }
 }
