@@ -17,16 +17,10 @@
 
 package org.apache.seatunnel.engine.server.dag.execution;
 
-import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.transform.SeaTunnelTransform;
-import org.apache.seatunnel.common.utils.SeaTunnelException;
 import org.apache.seatunnel.engine.common.config.EngineConfig;
 import org.apache.seatunnel.engine.common.utils.IdGenerator;
 import org.apache.seatunnel.engine.core.dag.actions.Action;
-import org.apache.seatunnel.engine.core.dag.actions.ShuffleAction;
-import org.apache.seatunnel.engine.core.dag.actions.ShuffleConfig;
-import org.apache.seatunnel.engine.core.dag.actions.ShuffleMultipleRowStrategy;
-import org.apache.seatunnel.engine.core.dag.actions.ShuffleStrategy;
 import org.apache.seatunnel.engine.core.dag.actions.SinkAction;
 import org.apache.seatunnel.engine.core.dag.actions.SinkConfig;
 import org.apache.seatunnel.engine.core.dag.actions.SourceAction;
@@ -47,11 +41,9 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
-import java.util.Optional;
 import java.util.Set;
 
 import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkArgument;
@@ -80,27 +72,21 @@ public class ExecutionPlanGenerator {
         Set<ExecutionEdge> executionEdges = generateExecutionEdges(logicalPlan.getEdges());
         log.debug("Phase 1: generate execution edge list {}", executionEdges);
 
-        executionEdges = generateShuffleEdges(executionEdges);
-        log.debug("Phase 2: generate shuffle edge list {}", executionEdges);
-
         executionEdges = generateTransformChainEdges(executionEdges);
-        log.debug("Phase 3: generate transform chain edge list {}", executionEdges);
+        log.debug("Phase 2: generate transform chain edge list {}", executionEdges);
 
         List<Pipeline> pipelines = generatePipelines(executionEdges);
-        log.debug("Phase 4: generate pipeline list {}", pipelines);
+        log.debug("Phase 3: generate pipeline list {}", pipelines);
 
         ExecutionPlan executionPlan = new ExecutionPlan(pipelines, jobImmutableInformation);
-        log.debug("Phase 5: generate execution plan: {}", executionPlan);
+        log.debug("Phase 4: generate execution plan: {}", executionPlan);
 
         return executionPlan;
     }
 
     public static Action recreateAction(Action action, Long id, int parallelism) {
         Action newAction;
-        if (action instanceof ShuffleAction) {
-            newAction =
-                    new ShuffleAction(id, action.getName(), ((ShuffleAction) action).getConfig());
-        } else if (action instanceof SinkAction) {
+        if (action instanceof SinkAction) {
             newAction =
                     new SinkAction<>(
                             id,
@@ -202,87 +188,6 @@ public class ExecutionPlanGenerator {
         return executionEdges;
     }
 
-    @SuppressWarnings("MagicNumber")
-    private Set<ExecutionEdge> generateShuffleEdges(Set<ExecutionEdge> executionEdges) {
-        Map<Long, List<ExecutionVertex>> targetVerticesMap = new LinkedHashMap<>();
-        Set<ExecutionVertex> sourceExecutionVertices = new HashSet<>();
-        executionEdges.forEach(
-                edge -> {
-                    ExecutionVertex leftVertex = edge.getLeftVertex();
-                    ExecutionVertex rightVertex = edge.getRightVertex();
-                    if (leftVertex.getAction() instanceof SourceAction) {
-                        sourceExecutionVertices.add(leftVertex);
-                    }
-                    targetVerticesMap
-                            .computeIfAbsent(leftVertex.getVertexId(), id -> new ArrayList<>())
-                            .add(rightVertex);
-                });
-        if (sourceExecutionVertices.size() != 1) {
-            return executionEdges;
-        }
-        ExecutionVertex sourceExecutionVertex = sourceExecutionVertices.stream().findFirst().get();
-        Action sourceAction = sourceExecutionVertex.getAction();
-        List<CatalogTable> producedCatalogTables = new ArrayList<>();
-        if (sourceAction instanceof SourceAction) {
-            try {
-                producedCatalogTables =
-                        ((SourceAction<?, ?, ?>) sourceAction)
-                                .getSource()
-                                .getProducedCatalogTables();
-            } catch (UnsupportedOperationException e) {
-            }
-        } else if (sourceAction instanceof TransformChainAction) {
-            return executionEdges;
-        } else {
-            throw new SeaTunnelException(
-                    "source action must be SourceAction or TransformChainAction");
-        }
-        if (producedCatalogTables.size() <= 1
-                || targetVerticesMap.get(sourceExecutionVertex.getVertexId()).size() <= 1) {
-            return executionEdges;
-        }
-
-        List<ExecutionVertex> sinkVertices =
-                targetVerticesMap.get(sourceExecutionVertex.getVertexId());
-        Optional<ExecutionVertex> hasOtherAction =
-                sinkVertices.stream()
-                        .filter(vertex -> !(vertex.getAction() instanceof SinkAction))
-                        .findFirst();
-        checkArgument(!hasOtherAction.isPresent());
-
-        Set<ExecutionEdge> newExecutionEdges = new LinkedHashSet<>();
-        ShuffleStrategy shuffleStrategy =
-                ShuffleMultipleRowStrategy.builder()
-                        .jobId(jobImmutableInformation.getJobId())
-                        .inputPartitions(sourceAction.getParallelism())
-                        .catalogTables(producedCatalogTables)
-                        .queueEmptyQueueTtl(
-                                (int)
-                                        (engineConfig.getCheckpointConfig().getCheckpointInterval()
-                                                * 3))
-                        .build();
-        ShuffleConfig shuffleConfig =
-                ShuffleConfig.builder().shuffleStrategy(shuffleStrategy).build();
-
-        long shuffleVertexId = idGenerator.getNextId();
-        String shuffleActionName = String.format("Shuffle [%s]", sourceAction.getName());
-        ShuffleAction shuffleAction =
-                new ShuffleAction(shuffleVertexId, shuffleActionName, shuffleConfig);
-        shuffleAction.setParallelism(sourceAction.getParallelism());
-        ExecutionVertex shuffleVertex =
-                new ExecutionVertex(shuffleVertexId, shuffleAction, shuffleAction.getParallelism());
-        ExecutionEdge sourceToShuffleEdge = new ExecutionEdge(sourceExecutionVertex, shuffleVertex);
-        newExecutionEdges.add(sourceToShuffleEdge);
-
-        for (ExecutionVertex sinkVertex : sinkVertices) {
-            sinkVertex.setParallelism(1);
-            sinkVertex.getAction().setParallelism(1);
-            ExecutionEdge shuffleToSinkEdge = new ExecutionEdge(shuffleVertex, sinkVertex);
-            newExecutionEdges.add(shuffleToSinkEdge);
-        }
-        return newExecutionEdges;
-    }
-
     private Set<ExecutionEdge> generateTransformChainEdges(Set<ExecutionEdge> executionEdges) {
         Map<Long, List<ExecutionVertex>> inputVerticesMap = new HashMap<>();
         Map<Long, List<ExecutionVertex>> targetVerticesMap = new HashMap<>();
