@@ -26,7 +26,6 @@ import org.apache.seatunnel.common.utils.function.ConsumerWithException;
 import org.apache.seatunnel.engine.common.utils.concurrent.CompletableFuture;
 import org.apache.seatunnel.engine.core.checkpoint.InternalCheckpointListener;
 import org.apache.seatunnel.engine.core.dag.actions.Action;
-import org.apache.seatunnel.engine.core.dag.actions.ShuffleAction;
 import org.apache.seatunnel.engine.core.dag.actions.SinkAction;
 import org.apache.seatunnel.engine.core.dag.actions.SourceAction;
 import org.apache.seatunnel.engine.core.dag.actions.TransformChainAction;
@@ -52,8 +51,6 @@ import org.apache.seatunnel.engine.server.task.flow.ActionFlowLifeCycle;
 import org.apache.seatunnel.engine.server.task.flow.FlowLifeCycle;
 import org.apache.seatunnel.engine.server.task.flow.IntermediateQueueFlowLifeCycle;
 import org.apache.seatunnel.engine.server.task.flow.OneInputFlowLifeCycle;
-import org.apache.seatunnel.engine.server.task.flow.ShuffleSinkFlowLifeCycle;
-import org.apache.seatunnel.engine.server.task.flow.ShuffleSourceFlowLifeCycle;
 import org.apache.seatunnel.engine.server.task.flow.SinkFlowLifeCycle;
 import org.apache.seatunnel.engine.server.task.flow.SourceFlowLifeCycle;
 import org.apache.seatunnel.engine.server.task.flow.TransformFlowLifeCycle;
@@ -61,7 +58,6 @@ import org.apache.seatunnel.engine.server.task.group.AbstractTaskGroupWithInterm
 import org.apache.seatunnel.engine.server.task.record.Barrier;
 import org.apache.seatunnel.engine.server.task.statemachine.SeaTunnelTaskState;
 
-import com.hazelcast.core.HazelcastInstance;
 import com.hazelcast.internal.metrics.MetricDescriptor;
 import com.hazelcast.internal.metrics.MetricsCollectionContext;
 import com.hazelcast.spi.impl.operationservice.impl.InvocationFuture;
@@ -238,27 +234,6 @@ public abstract class SeaTunnelTask extends AbstractTask {
                                 this,
                                 new SeaTunnelTransformCollector(flowLifeCycles),
                                 completableFuture);
-            } else if (f.getAction() instanceof ShuffleAction) {
-                ShuffleAction shuffleAction = (ShuffleAction) f.getAction();
-                HazelcastInstance hazelcastInstance = getExecutionContext().getInstance();
-                if (flow.getNext().isEmpty()) {
-                    lifeCycle =
-                            new ShuffleSinkFlowLifeCycle(
-                                    this,
-                                    indexID,
-                                    shuffleAction,
-                                    hazelcastInstance,
-                                    completableFuture);
-                } else {
-                    lifeCycle =
-                            new ShuffleSourceFlowLifeCycle(
-                                    this,
-                                    indexID,
-                                    shuffleAction,
-                                    hazelcastInstance,
-                                    completableFuture);
-                }
-                outputs = flowLifeCycles;
             } else {
                 throw new UnknownActionException(f.getAction());
             }
