@@ -17,9 +17,13 @@
 
 package org.apache.seatunnel.engine.server.task.flow;
 
+import org.apache.seatunnel.api.table.schema.event.SchemaChangeEvent;
 import org.apache.seatunnel.api.table.type.Record;
 import org.apache.seatunnel.api.transform.Collector;
+import org.apache.seatunnel.api.transform.SeaTunnelFlatMapTransform;
+import org.apache.seatunnel.api.transform.SeaTunnelMapTransform;
 import org.apache.seatunnel.api.transform.SeaTunnelTransform;
+import org.apache.seatunnel.engine.common.utils.concurrent.CompletableFuture;
 import org.apache.seatunnel.engine.core.dag.actions.TransformChainAction;
 import org.apache.seatunnel.engine.server.checkpoint.ActionStateKey;
 import org.apache.seatunnel.engine.server.checkpoint.ActionSubtaskState;
@@ -27,12 +31,14 @@ import org.apache.seatunnel.engine.server.checkpoint.CheckpointBarrier;
 import org.apache.seatunnel.engine.server.task.SeaTunnelTask;
 import org.apache.seatunnel.engine.server.task.record.Barrier;
 
+import org.apache.commons.collections4.CollectionUtils;
+
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
-import java.util.concurrent.CompletableFuture;
 
 @Slf4j
 public class TransformFlowLifeCycle<T> extends ActionFlowLifeCycle
@@ -84,29 +90,93 @@ public class TransformFlowLifeCycle<T> extends ActionFlowLifeCycle
             // ack after #addState
             runningTask.ack(barrier);
             collector.collect(record);
+        } else if (record.getData() instanceof SchemaChangeEvent) {
+            if (prepareClose) {
+                return;
+            }
+            SchemaChangeEvent event = (SchemaChangeEvent) record.getData();
+            for (SeaTunnelTransform<T> t : transform) {
+                SchemaChangeEvent eventBefore = event;
+                event = t.mapSchemaChangeEvent(eventBefore);
+                if (event == null) {
+                    log.info(
+                            "Transform[{}] filtered schema change event {}",
+                            t.getPluginName(),
+                            eventBefore);
+                    break;
+                }
+                log.info(
+                        "Transform[{}] input schema change event {} and output schema change event {}",
+                        t.getPluginName(),
+                        eventBefore,
+                        event);
+            }
+            if (event != null) {
+                collector.collect(new Record<>(event));
+            }
         } else {
             if (prepareClose) {
                 return;
             }
             T inputData = (T) record.getData();
-            T outputData = inputData;
-            for (SeaTunnelTransform<T> t : transform) {
-                outputData = t.map(inputData);
-                log.debug("Transform[{}] input row {} and output row {}", t, inputData, outputData);
-                if (outputData == null) {
-                    log.trace("Transform[{}] filtered data row {}", t, inputData);
-                    break;
-                }
-
-                inputData = outputData;
-            }
-            if (outputData != null) {
+            List<T> outputDataList = transform(inputData);
+            if (!outputDataList.isEmpty()) {
                 // todo log metrics
-                collector.collect(new Record<>(outputData));
+                for (T outputData : outputDataList) {
+                    collector.collect(new Record<>(outputData));
+                }
             }
         }
     }
 
+    public List<T> transform(T inputData) {
+        if (transform.isEmpty()) {
+            return Collections.singletonList(inputData);
+        }
+
+        List<T> dataList = new ArrayList<>();
+        dataList.add(inputData);
+
+        for (SeaTunnelTransform<T> transformer : transform) {
+            List<T> nextInputDataList = new ArrayList<>();
+            if (transformer instanceof SeaTunnelFlatMapTransform) {
+                SeaTunnelFlatMapTransform<T> transformDecorator =
+                        (SeaTunnelFlatMapTransform<T>) transformer;
+                for (T data : dataList) {
+                    List<T> outputDataArray = transformDecorator.flatMap(data);
+                    log.debug(
+                            "Transform[{}] input row {} and output row {}",
+                            transformer,
+                            data,
+                            outputDataArray);
+                    if (CollectionUtils.isNotEmpty(outputDataArray)) {
+                        nextInputDataList.addAll(outputDataArray);
+                    }
+                }
+            } else if (transformer instanceof SeaTunnelMapTransform) {
+                for (T data : dataList) {
+                    SeaTunnelMapTransform<T> transformDecorator =
+                            (SeaTunnelMapTransform<T>) transformer;
+                    T outputData = transformDecorator.map(data);
+                    log.debug(
+                            "Transform[{}] input row {} and output row {}",
+                            transformer,
+                            data,
+                            outputData);
+                    if (outputData == null) {
+                        log.trace("Transform[{}] filtered data row {}", transformer, data);
+                        continue;
+                    }
+                    nextInputDataList.add(outputData);
+                }
+            }
+
+            dataList = nextInputDataList;
+        }
+
+        return dataList;
+    }
+
     @Override
     public void restoreState(List<ActionSubtaskState> actionStateList) throws Exception {
         // nothing
