@@ -21,7 +21,7 @@ import org.apache.seatunnel.shade.com.typesafe.config.Config;
 
 import org.apache.seatunnel.api.common.JobContext;
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
-import org.apache.seatunnel.api.env.EnvCommonOptions;
+import org.apache.seatunnel.api.options.EnvCommonOptions;
 import org.apache.seatunnel.common.Constants;
 import org.apache.seatunnel.common.config.Common;
 import org.apache.seatunnel.common.config.DeployMode;
@@ -275,8 +275,8 @@ public class ConnectorPackageServiceTest {
                 new JobImmutableInformation(
                         jobId,
                         "Test",
-                        instance1.getSerializationService().toData(logicalDag),
-                        logicalDag.getJobConfig(),
+                        instance1.getSerializationService(),
+                        logicalDag,
                         jarUrls,
                         connectorJarIdentifiers);
 
