@@ -24,6 +24,8 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ObjectNode
 
 import org.apache.seatunnel.api.serialization.DeserializationSchema;
 import org.apache.seatunnel.api.source.Collector;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.type.RowKind;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
@@ -32,7 +34,10 @@ import org.apache.seatunnel.common.exception.CommonError;
 import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
 import org.apache.seatunnel.format.json.JsonDeserializationSchema;
 
+import lombok.NonNull;
+
 import java.io.IOException;
+import java.util.Optional;
 import java.util.regex.Pattern;
 
 import static java.lang.String.format;
@@ -64,9 +69,9 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
 
     private static final String OP_ALTER = "ALTER";
 
-    private String database;
+    private final String database;
 
-    private String table;
+    private final String table;
 
     /** Names of fields. */
     private final String[] fieldNames;
@@ -74,7 +79,7 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
     /** Number of fields. */
     private final int fieldCount;
 
-    private boolean ignoreParseErrors;
+    private final boolean ignoreParseErrors;
 
     /** Pattern of the specific database. */
     private final Pattern databasePattern;
@@ -84,21 +89,22 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
 
     private final JsonDeserializationSchema jsonDeserializer;
 
-    private final SeaTunnelRowType physicalRowType;
+    private final SeaTunnelRowType seaTunnelRowType;
+    private final CatalogTable catalogTable;
 
     public CanalJsonDeserializationSchema(
-            SeaTunnelRowType physicalRowType,
+            @NonNull CatalogTable catalogTable,
             String database,
             String table,
             boolean ignoreParseErrors) {
-        this.physicalRowType = physicalRowType;
-        final SeaTunnelRowType jsonRowType = createJsonRowType(physicalRowType);
+        this.catalogTable = catalogTable;
+        this.seaTunnelRowType = catalogTable.getSeaTunnelRowType();
         this.jsonDeserializer =
-                new JsonDeserializationSchema(false, ignoreParseErrors, jsonRowType);
+                new JsonDeserializationSchema(catalogTable, false, ignoreParseErrors);
         this.database = database;
         this.table = table;
-        this.fieldNames = physicalRowType.getFieldNames();
-        this.fieldCount = physicalRowType.getTotalFields();
+        this.fieldNames = seaTunnelRowType.getFieldNames();
+        this.fieldCount = seaTunnelRowType.getTotalFields();
         this.ignoreParseErrors = ignoreParseErrors;
         this.databasePattern = database == null ? null : Pattern.compile(database);
         this.tablePattern = table == null ? null : Pattern.compile(table);
@@ -112,10 +118,13 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
 
     @Override
     public SeaTunnelDataType<SeaTunnelRow> getProducedType() {
-        return this.physicalRowType;
+        return this.seaTunnelRowType;
     }
 
     public void deserialize(ObjectNode jsonNode, Collector<SeaTunnelRow> out) throws IOException {
+        TablePath tablePath =
+                Optional.ofNullable(catalogTable).map(CatalogTable::getTablePath).orElse(null);
+
         try {
             if (database != null
                     && !databasePattern.matcher(jsonNode.get(FIELD_DATABASE).asText()).matches()) {
@@ -127,47 +136,65 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
             }
 
             JsonNode dataNode = jsonNode.get(FIELD_DATA);
-            String type = jsonNode.get(FIELD_TYPE).asText();
+            String op = jsonNode.get(FIELD_TYPE).asText();
             // When a null value is encountered, an exception needs to be thrown for easy sensing
             if (dataNode == null || dataNode.isNull()) {
                 // We'll skip the query or create or alter event data
-                if (OP_QUERY.equals(type) || OP_CREATE.equals(type) || OP_ALTER.equals(type)) {
+                if (OP_QUERY.equals(op) || OP_CREATE.equals(op) || OP_ALTER.equals(op)) {
                     return;
                 }
                 throw new IllegalStateException(
                         format("Null data value '%s' Cannot send downstream", jsonNode));
             }
-            if (OP_INSERT.equals(type)) {
-                for (int i = 0; i < dataNode.size(); i++) {
-                    SeaTunnelRow row = convertJsonNode(dataNode.get(i));
-                    out.collect(row);
-                }
-            } else if (OP_UPDATE.equals(type)) {
-                final ArrayNode oldNode = (ArrayNode) jsonNode.get(FIELD_OLD);
-                for (int i = 0; i < dataNode.size(); i++) {
-                    SeaTunnelRow after = convertJsonNode(dataNode.get(i));
-                    SeaTunnelRow before = convertJsonNode(oldNode.get(i));
-                    for (int f = 0; f < fieldCount; f++) {
-                        if (before.isNullAt(f) && oldNode.findValue(fieldNames[f]) == null) {
-                            // fields in "old" (before) means the fields are changed
-                            // fields not in "old" (before) means the fields are not changed
-                            // so we just copy the not changed fields into before
-                            before.setField(f, after.getField(f));
+
+            switch (op) {
+                case OP_INSERT:
+                    for (int i = 0; i < dataNode.size(); i++) {
+                        SeaTunnelRow row = convertJsonNode(dataNode.get(i));
+                        if (tablePath != null && !tablePath.toString().isEmpty()) {
+                            row.setTableId(tablePath.toString());
                         }
+                        out.collect(row);
                     }
-                    before.setRowKind(RowKind.UPDATE_BEFORE);
-                    after.setRowKind(RowKind.UPDATE_AFTER);
-                    out.collect(before);
-                    out.collect(after);
-                }
-            } else if (OP_DELETE.equals(type)) {
-                for (int i = 0; i < dataNode.size(); i++) {
-                    SeaTunnelRow row = convertJsonNode(dataNode.get(i));
-                    row.setRowKind(RowKind.DELETE);
-                    out.collect(row);
-                }
-            } else {
-                throw new IllegalStateException(format("Unknown operation type '%s'.", type));
+                    break;
+                case OP_UPDATE:
+                    final ArrayNode oldNode = (ArrayNode) jsonNode.get(FIELD_OLD);
+                    for (int i = 0; i < dataNode.size(); i++) {
+                        SeaTunnelRow after = convertJsonNode(dataNode.get(i));
+                        SeaTunnelRow before = convertJsonNode(oldNode.get(i));
+                        for (int f = 0; f < fieldCount; f++) {
+                            if (before.isNullAt(f) && oldNode.findValue(fieldNames[f]) == null) {
+                                // fields in "old" (before) means the fields are changed
+                                // fields not in "old" (before) means the fields are not changed
+                                // so we just copy the not changed fields into before
+                                before.setField(f, after.getField(f));
+                            }
+                        }
+                        before.setRowKind(RowKind.UPDATE_BEFORE);
+                        if (tablePath != null && !tablePath.toString().isEmpty()) {
+                            before.setTableId(tablePath.toString());
+                        }
+                        after.setRowKind(RowKind.UPDATE_AFTER);
+                        if (tablePath != null && !tablePath.toString().isEmpty()) {
+                            after.setTableId(tablePath.toString());
+                        }
+                        out.collect(before);
+                        out.collect(after);
+                    }
+                    break;
+                case OP_DELETE:
+                    for (int i = 0; i < dataNode.size(); i++) {
+                        SeaTunnelRow row = convertJsonNode(dataNode.get(i));
+                        row.setRowKind(RowKind.DELETE);
+                        if (tablePath != null && !tablePath.toString().isEmpty()) {
+                            row.setTableId(tablePath.toString());
+                        }
+                        out.collect(row);
+                    }
+                    break;
+                default:
+                    throw new IllegalStateException(
+                            String.format("Unknown operation type '%s'.", op));
             }
         } catch (RuntimeException e) {
             if (!ignoreParseErrors) {
@@ -177,31 +204,26 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
     }
 
     private ObjectNode convertBytes(byte[] message) throws SeaTunnelRuntimeException {
+        if (message == null || message.length == 0) {
+            return null;
+        }
+
         try {
             return (ObjectNode) jsonDeserializer.deserializeToJsonNode(message);
         } catch (Throwable t) {
-            throw CommonError.jsonOperationError(FORMAT, new String(message), t);
+            if (!ignoreParseErrors) {
+                throw CommonError.jsonOperationError(FORMAT, new String(message), t);
+            }
+            return null;
         }
     }
 
     @Override
     public void deserialize(byte[] message, Collector<SeaTunnelRow> out) throws IOException {
-        if (message == null) {
-            return;
+        ObjectNode jsonNodes = convertBytes(message);
+        if (jsonNodes != null) {
+            deserialize(convertBytes(message), out);
         }
-
-        ObjectNode jsonNode;
-        try {
-            jsonNode = convertBytes(message);
-        } catch (SeaTunnelRuntimeException cause) {
-            if (!ignoreParseErrors) {
-                throw cause;
-            } else {
-                return;
-            }
-        }
-
-        deserialize(jsonNode, out);
     }
 
     private SeaTunnelRow convertJsonNode(JsonNode root) {
@@ -218,8 +240,8 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
     // ------------------------------------------------------------------------------------------
 
     /** Creates A builder for building a {@link CanalJsonDeserializationSchema}. */
-    public static Builder builder(SeaTunnelRowType physicalDataType) {
-        return new Builder(physicalDataType);
+    public static Builder builder(CatalogTable catalogTable) {
+        return new Builder(catalogTable);
     }
 
     public static class Builder {
@@ -230,10 +252,10 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
 
         private String table = null;
 
-        private final SeaTunnelRowType physicalDataType;
+        private CatalogTable catalogTable;
 
-        public Builder(SeaTunnelRowType physicalDataType) {
-            this.physicalDataType = physicalDataType;
+        public Builder(CatalogTable catalogTable) {
+            this.catalogTable = catalogTable;
         }
 
         public Builder setDatabase(String database) {
@@ -251,9 +273,14 @@ public class CanalJsonDeserializationSchema implements DeserializationSchema<Sea
             return this;
         }
 
+        public Builder setCatalogTable(CatalogTable catalogTable) {
+            this.catalogTable = catalogTable;
+            return this;
+        }
+
         public CanalJsonDeserializationSchema build() {
             return new CanalJsonDeserializationSchema(
-                    physicalDataType, database, table, ignoreParseErrors);
+                    catalogTable, database, table, ignoreParseErrors);
         }
     }
 }
