@@ -20,16 +20,18 @@ package org.apache.seatunnel.transform.dynamiccompile;
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
+import org.apache.seatunnel.api.table.type.SeaTunnelRow;
+import org.apache.seatunnel.api.table.type.SeaTunnelRowAccessor;
 import org.apache.seatunnel.common.utils.FileUtils;
 import org.apache.seatunnel.common.utils.ReflectionUtils;
 import org.apache.seatunnel.transform.common.MultipleFieldOutputTransform;
-import org.apache.seatunnel.transform.common.SeaTunnelRowAccessor;
 import org.apache.seatunnel.transform.dynamiccompile.parse.AbstractParse;
 import org.apache.seatunnel.transform.dynamiccompile.parse.GroovyClassParse;
 import org.apache.seatunnel.transform.dynamiccompile.parse.JavaClassParse;
 import org.apache.seatunnel.transform.exception.TransformException;
 
 import java.nio.file.Paths;
+import java.util.Optional;
 
 import static org.apache.seatunnel.transform.dynamiccompile.CompileTransformErrorCode.COMPILE_TRANSFORM_ERROR_CODE;
 
@@ -42,6 +44,8 @@ public class DynamicCompileTransform extends MultipleFieldOutputTransform {
 
     private final String sourceCode;
 
+    private final boolean compatibilityMode;
+
     private final CompilePattern compilePattern;
 
     private AbstractParse DynamicCompileParse;
@@ -68,6 +72,9 @@ public class DynamicCompileTransform extends MultipleFieldOutputTransform {
                                     readonlyConfig.get(
                                             DynamicCompileTransformConfig.ABSOLUTE_PATH)));
         }
+        compatibilityMode =
+                sourceCode.contains(
+                        org.apache.seatunnel.transform.common.SeaTunnelRowAccessor.class.getName());
     }
 
     @Override
@@ -98,14 +105,24 @@ public class DynamicCompileTransform extends MultipleFieldOutputTransform {
         try {
             result =
                     ReflectionUtils.invoke(
-                            getCompileLanguageInstance(), getInlineOutputFieldValues, inputRow);
-
+                            getCompileLanguageInstance(),
+                            getInlineOutputFieldValues,
+                            getCompatibilityAccessor(inputRow));
         } catch (Exception e) {
             throw new TransformException(COMPILE_TRANSFORM_ERROR_CODE, e.getMessage());
         }
         return (Object[]) result;
     }
 
+    private Object getCompatibilityAccessor(SeaTunnelRowAccessor inputRow) {
+        if (compatibilityMode) {
+            Optional<Object> field = ReflectionUtils.getField(inputRow, "row");
+            SeaTunnelRow row = (SeaTunnelRow) field.get();
+            return new org.apache.seatunnel.transform.common.SeaTunnelRowAccessor(row);
+        }
+        return inputRow;
+    }
+
     private Object getCompileLanguageInstance()
             throws InstantiationException, IllegalAccessException {
         Class<?> compileClass = DynamicCompileParse.parseClassSourceCode(sourceCode);
