@@ -49,18 +49,22 @@ public class SeaTunnelBatchWrite<StateT, CommitInfoT, AggregatedCommitInfoT>
 
     private MultiTableResourceManager resourceManager;
 
-    private final CatalogTable catalogTable;
+    private final CatalogTable[] catalogTables;
 
     private final String jobId;
 
+    private final int parallelism;
+
     public SeaTunnelBatchWrite(
             SeaTunnelSink<SeaTunnelRow, StateT, CommitInfoT, AggregatedCommitInfoT> sink,
-            CatalogTable catalogTable,
-            String jobId)
+            CatalogTable[] catalogTables,
+            String jobId,
+            int parallelism)
             throws IOException {
         this.sink = sink;
-        this.catalogTable = catalogTable;
+        this.catalogTables = catalogTables;
         this.jobId = jobId;
+        this.parallelism = parallelism;
         this.aggregatedCommitter = sink.createAggregatedCommitter().orElse(null);
         if (aggregatedCommitter != null) {
             if (this.aggregatedCommitter instanceof SupportResourceShare) {
@@ -78,7 +82,7 @@ public class SeaTunnelBatchWrite<StateT, CommitInfoT, AggregatedCommitInfoT>
 
     @Override
     public DataWriterFactory createBatchWriterFactory(PhysicalWriteInfo info) {
-        return new SeaTunnelSparkDataWriterFactory<>(sink, catalogTable, jobId);
+        return new SeaTunnelSparkDataWriterFactory<>(sink, catalogTables, jobId, parallelism);
     }
 
     @Override
